@@ -58,7 +58,7 @@ extern int main_debug;
 #include "parser/parser-expr-parser.h"
 #include "rewrite/rewrite-expr-parser.h"
 #include "logmatcher.h"
-#include "logthrdestdrv.h"
+#include "logthrdest/logthrdestdrv.h"
 #include "logthrsource/logthrsourcedrv.h"
 #include "str-utils.h"
 
@@ -144,6 +144,7 @@ extern struct _StatsOptions *last_stats_options;
     KW_MIN_IW_SIZE_PER_READER = 10085,
     KW_BATCH_LINES = 10087,
     KW_BATCH_TIMEOUT = 10088,
+    KW_TRIM_LARGE_MESSAGES = 10089,
     KW_CHAIN_HOSTNAMES = 10090,
     KW_NORMALIZE_HOSTNAMES = 10091,
     KW_KEEP_HOSTNAME = 10092,
@@ -216,15 +217,16 @@ extern struct _StatsOptions *last_stats_options;
     KW_ENDIF = 10411,
     LL_DOTDOT = 10420,
     LL_DOTDOTDOT = 10421,
-    LL_IDENTIFIER = 10422,
-    LL_NUMBER = 10423,
-    LL_FLOAT = 10424,
-    LL_STRING = 10425,
-    LL_TOKEN = 10426,
-    LL_BLOCK = 10427,
-    LL_PRAGMA = 10428,
-    LL_EOL = 10429,
-    LL_ERROR = 10430,
+    LL_PRAGMA = 10422,
+    LL_EOL = 10423,
+    LL_ERROR = 10424,
+    LL_ARROW = 10425,
+    LL_IDENTIFIER = 10430,
+    LL_NUMBER = 10431,
+    LL_FLOAT = 10432,
+    LL_STRING = 10433,
+    LL_TOKEN = 10434,
+    LL_BLOCK = 10435,
     KW_VALUE_PAIRS = 10500,
     KW_EXCLUDE = 10502,
     KW_PAIR = 10503,
@@ -292,6 +294,7 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_MIN_IW_SIZE_PER_READER 10085
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
+#define KW_TRIM_LARGE_MESSAGES 10089
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
@@ -364,15 +367,16 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_ENDIF 10411
 #define LL_DOTDOT 10420
 #define LL_DOTDOTDOT 10421
-#define LL_IDENTIFIER 10422
-#define LL_NUMBER 10423
-#define LL_FLOAT 10424
-#define LL_STRING 10425
-#define LL_TOKEN 10426
-#define LL_BLOCK 10427
-#define LL_PRAGMA 10428
-#define LL_EOL 10429
-#define LL_ERROR 10430
+#define LL_PRAGMA 10422
+#define LL_EOL 10423
+#define LL_ERROR 10424
+#define LL_ARROW 10425
+#define LL_IDENTIFIER 10430
+#define LL_NUMBER 10431
+#define LL_FLOAT 10432
+#define LL_STRING 10433
+#define LL_TOKEN 10434
+#define LL_BLOCK 10435
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
